#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tar-conduit
version:              0.4.1
visibility:           public
id:                   tar-conduit-0.4.1-FFztJNZeCpp5afcpDdqot9
key:                  tar-conduit-0.4.1-FFztJNZeCpp5afcpDdqot9
license:              MIT
maintainer:
    michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch

author:               Michael Snoyman
homepage:             https://github.com/snoyberg/tar-conduit#readme
synopsis:             Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.

category:             Data Conduit
abi:                  158352e09e73a8ca6257e8c60f32b3ec
exposed:              True
exposed-modules:      Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules:       Data.Conduit.Tar.Unix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tar-conduit-0.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tar-conduit-0.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tar-conduit-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar-conduit
hs-libraries:         HStar-conduit-0.4.1-FFztJNZeCpp5afcpDdqot9
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-bHMGfLNlzWFeFHMt1zPL0 containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    safe-exceptions-0.1.7.4-HWCEItuykIj9L5YUgdbaCI text-2.0.2
    unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html:         /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

